@@ -52,11 +52,11 @@ struct private_dumm_t {
 /**
  * Implementation of dumm_t.create_guest.
  */
-static guest_t* create_guest(private_dumm_t *this, char *name, char *kernel, 
+static guest_t* create_guest(private_dumm_t *this, char *name, char *kernel,
 							 char *master, char *args)
 {
 	guest_t *guest;
-	
+
 	guest = guest_create(this->guest_dir, name, kernel, master, args);
 	if (guest)
 	{
@@ -82,7 +82,7 @@ static void delete_guest(private_dumm_t *this, guest_t *guest)
 	{
 		char buf[512];
 		int len;
-		
+
 		len = snprintf(buf, sizeof(buf), "rm -Rf %s/%s",
 					   this->guest_dir, guest->get_name(guest));
 		guest->destroy(guest);
@@ -99,7 +99,7 @@ static void delete_guest(private_dumm_t *this, guest_t *guest)
 static bridge_t* create_bridge(private_dumm_t *this, char *name)
 {
 	bridge_t *bridge;
-	
+
 	bridge = bridge_create(name);
 	if (bridge)
 	{
@@ -128,16 +128,16 @@ static void delete_bridge(private_dumm_t *this, bridge_t *bridge)
 }
 
 /**
- * disable the currently enabled template 
+ * disable the currently enabled template
  */
 static void clear_template(private_dumm_t *this)
 {
 	enumerator_t *enumerator;
 	guest_t *guest;
-	
+
 	free(this->template);
 	this->template = NULL;
-	
+
 	enumerator = this->guests->create_enumerator(this->guests);
 	while (enumerator->enumerate(enumerator, (void**)&guest))
 	{
@@ -153,19 +153,19 @@ static bool load_template(private_dumm_t *this, char *dir)
 {
 	enumerator_t *enumerator;
 	guest_t *guest;
-	
+
 	clear_template(this);
-	
+
 	if (dir == NULL)
 	{
 		return TRUE;
 	}
 	if (strlen(dir) > PATH_MAX)
 	{
-		DBG1("template directory string '%s' is too long", dir);
+		DBG1(DBG_LIB, "template directory string '%s' is too long", dir);
 		return FALSE;
 	}
-	
+
 	if (asprintf(&this->template, "%s/%s", TEMPLATE_DIR, dir) < 0)
 	{
 		this->template = NULL;
@@ -175,7 +175,8 @@ static bool load_template(private_dumm_t *this, char *dir)
 	{	/* does not exist, create template */
 		if (!mkdir_p(this->template, PERME))
 		{
-			DBG1("creating template directory '%s' failed: %m", this->template);
+			DBG1(DBG_LIB, "creating template directory '%s' failed: %m",
+				 this->template);
 			return FALSE;
 		}
 	}
@@ -210,7 +211,7 @@ static bool template_enumerate(template_enumerator_t *this, char **template)
 {
 	struct stat st;
 	char *rel;
-	
+
 	while (this->inner->enumerate(this->inner, &rel, NULL, &st))
 	{
 		if (S_ISDIR(st.st_mode) && *rel != '.')
@@ -237,12 +238,12 @@ static void template_enumerator_destroy(template_enumerator_t *this)
 static enumerator_t* create_template_enumerator(private_dumm_t *this)
 {
 	template_enumerator_t *enumerator;
-	
+
 	enumerator = malloc_thing(template_enumerator_t);
 	enumerator->public.enumerate = (void*)template_enumerate;
 	enumerator->public.destroy = (void*)template_enumerator_destroy;
 	enumerator->inner = enumerator_create_directory(TEMPLATE_DIR);
-	
+
 	return &enumerator->public;
 }
 
@@ -253,16 +254,16 @@ static void destroy(private_dumm_t *this)
 {
 	enumerator_t *enumerator;
 	guest_t *guest;
-	
+
 	this->bridges->destroy_offset(this->bridges, offsetof(bridge_t, destroy));
-	
+
 	enumerator = this->guests->create_enumerator(this->guests);
 	while (enumerator->enumerate(enumerator, (void**)&guest))
 	{
 		guest->stop(guest, NULL);
 	}
 	enumerator->destroy(enumerator);
-	
+
 	while (this->guests->remove_last(this->guests, (void**)&guest) == SUCCESS)
 	{
 		guest->destroy(guest);
@@ -282,13 +283,13 @@ static void load_guests(private_dumm_t *this)
 	DIR *dir;
 	struct dirent *ent;
 	guest_t *guest;
-	
+
 	dir = opendir(this->guest_dir);
 	if (dir == NULL)
 	{
 		return;
 	}
-	
+
 	while ((ent = readdir(dir)))
 	{
 		if (*ent->d_name == '.')
@@ -302,7 +303,8 @@ static void load_guests(private_dumm_t *this)
 		}
 		else
 		{
-			DBG1("loading guest in directory '%s' failed, skipped", ent->d_name);
+			DBG1(DBG_LIB, "loading guest in directory '%s' failed, skipped",
+				 ent->d_name);
 		}
 	}
 	closedir(dir);
@@ -315,7 +317,7 @@ dumm_t *dumm_create(char *dir)
 {
 	char cwd[PATH_MAX];
 	private_dumm_t *this = malloc_thing(private_dumm_t);
-	
+
 	this->public.create_guest = (guest_t*(*)(dumm_t*,char*,char*,char*,char*))create_guest;
 	this->public.create_guest_enumerator = (enumerator_t*(*)(dumm_t*))create_guest_enumerator;
 	this->public.delete_guest = (void(*)(dumm_t*,guest_t*))delete_guest;
@@ -325,7 +327,7 @@ dumm_t *dumm_create(char *dir)
 	this->public.load_template = (bool(*)(dumm_t*, char *name))load_template;
 	this->public.create_template_enumerator = (enumerator_t*(*)(dumm_t*))create_template_enumerator;
 	this->public.destroy = (void(*)(dumm_t*))destroy;
-	
+
 	if (dir && *dir == '/')
 	{
 		this->dir = strdup(dir);
@@ -356,15 +358,16 @@ dumm_t *dumm_create(char *dir)
 	}
 	this->guests = linked_list_create();
 	this->bridges = linked_list_create();
-	
+
 	if (this->dir == NULL || this->guest_dir == NULL ||
 		(mkdir(this->guest_dir, PERME) < 0 && errno != EEXIST))
 	{
-		DBG1("creating guest directory '%s' failed: %m", this->guest_dir);
+		DBG1(DBG_LIB, "creating guest directory '%s' failed: %m",
+			 this->guest_dir);
 		destroy(this);
 		return NULL;
 	}
-	
+
 	load_guests(this);
 	return &this->public;
 }
