@@ -17,6 +17,8 @@
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
 #undef PACKAGE_STRING
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_URL
 #include <ruby.h>
 
 /**
@@ -26,10 +28,10 @@ int main(int argc, char *argv[])
 {
 	int state, i;
 	char buf[512];
-	
+
 	ruby_init();
 	ruby_init_loadpath();
-	
+
 	rb_eval_string_protect("require 'dumm' and include Dumm", &state);
 	if (state)
 	{
@@ -53,7 +55,7 @@ int main(int argc, char *argv[])
 	{
 		rb_p(ruby_errinfo);
 	}
-	
+
 	ruby_finalize();
 	return 0;
 }
