@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  */
- 
+
 /**
  * @defgroup asn1i asn1
  * @{ @ingroup asn1
@@ -25,56 +25,57 @@
 
 #include <stdarg.h>
 
-#include <utils.h>
-#include <chunk.h>
+#include <library.h>
 
 /**
  * Definition of some primitive ASN1 types
  */
 typedef enum {
-    ASN1_EOC =				0x00,
-    ASN1_BOOLEAN =			0x01,
-    ASN1_INTEGER =			0x02,
-    ASN1_BIT_STRING =		0x03,
-    ASN1_OCTET_STRING = 	0x04,
-    ASN1_NULL = 			0x05,
-    ASN1_OID =				0x06,
-    ASN1_ENUMERATED =		0x0A,
-    ASN1_UTF8STRING =		0x0C,
-    ASN1_NUMERICSTRING =	0x12,
-    ASN1_PRINTABLESTRING =	0x13,
-    ASN1_T61STRING =		0x14,
-    ASN1_VIDEOTEXSTRING =	0x15,
-    ASN1_IA5STRING =		0x16,
-    ASN1_UTCTIME =			0x17,
-    ASN1_GENERALIZEDTIME =	0x18,
-    ASN1_GRAPHICSTRING =	0x19,
-    ASN1_VISIBLESTRING = 	0x1A,
-    ASN1_GENERALSTRING =	0x1B,
-    ASN1_UNIVERSALSTRING =	0x1C,
-    ASN1_BMPSTRING =		0x1E,
+	ASN1_EOC =				0x00,
+	ASN1_BOOLEAN =			0x01,
+	ASN1_INTEGER =			0x02,
+	ASN1_BIT_STRING =		0x03,
+	ASN1_OCTET_STRING = 	0x04,
+	ASN1_NULL = 			0x05,
+	ASN1_OID =				0x06,
+	ASN1_ENUMERATED =		0x0A,
+	ASN1_UTF8STRING =		0x0C,
+	ASN1_NUMERICSTRING =	0x12,
+	ASN1_PRINTABLESTRING =	0x13,
+	ASN1_T61STRING =		0x14,
+	ASN1_VIDEOTEXSTRING =	0x15,
+	ASN1_IA5STRING =		0x16,
+	ASN1_UTCTIME =			0x17,
+	ASN1_GENERALIZEDTIME =	0x18,
+	ASN1_GRAPHICSTRING =	0x19,
+	ASN1_VISIBLESTRING = 	0x1A,
+	ASN1_GENERALSTRING =	0x1B,
+	ASN1_UNIVERSALSTRING =	0x1C,
+	ASN1_BMPSTRING =		0x1E,
 
-    ASN1_CONSTRUCTED =		0x20,
+	ASN1_CONSTRUCTED =		0x20,
 
-    ASN1_SEQUENCE =			0x30,
-    ASN1_SET =				0x31,
+	ASN1_SEQUENCE =			0x30,
+	ASN1_SET =				0x31,
 
-    ASN1_CONTEXT_S_0 =		0x80,
-    ASN1_CONTEXT_S_1 =		0x81,
-    ASN1_CONTEXT_S_2 =		0x82,
-    ASN1_CONTEXT_S_3 =		0x83,
-    ASN1_CONTEXT_S_4 =		0x84,
-    ASN1_CONTEXT_S_5 =		0x85,
-    ASN1_CONTEXT_S_6 =		0x86,
-    ASN1_CONTEXT_S_7 =		0x87,
-    ASN1_CONTEXT_S_8 =		0x88,
+	ASN1_CONTEXT_S_0 =		0x80,
+	ASN1_CONTEXT_S_1 =		0x81,
+	ASN1_CONTEXT_S_2 =		0x82,
+	ASN1_CONTEXT_S_3 =		0x83,
+	ASN1_CONTEXT_S_4 =		0x84,
+	ASN1_CONTEXT_S_5 =		0x85,
+	ASN1_CONTEXT_S_6 =		0x86,
+	ASN1_CONTEXT_S_7 =		0x87,
+	ASN1_CONTEXT_S_8 =		0x88,
 
-    ASN1_CONTEXT_C_0 =		0xA0,
-    ASN1_CONTEXT_C_1 =		0xA1,
-    ASN1_CONTEXT_C_2 =		0xA2,
-    ASN1_CONTEXT_C_3 =		0xA3,
-    ASN1_CONTEXT_C_4 =		0xA4,
-    ASN1_CONTEXT_C_5 =		0xA5
+	ASN1_CONTEXT_C_0 =		0xA0,
+	ASN1_CONTEXT_C_1 =		0xA1,
+	ASN1_CONTEXT_C_2 =		0xA2,
+	ASN1_CONTEXT_C_3 =		0xA3,
+	ASN1_CONTEXT_C_4 =		0xA4,
+	ASN1_CONTEXT_C_5 =		0xA5,
+
+	ASN1_INVALID = 			0x100,
 } asn1_t;
 
 #define ASN1_INVALID_LENGTH	0xffffffff
@@ -90,10 +91,10 @@ extern const chunk_t ASN1_INTEGER_2;
 /** Some ASN.1 analysis functions */
 
 /**
- * Returns some popular algorithmIdentifiers
+ * Build an algorithmIdentifier from a known OID.
  *
  * @param oid		known OID index
- * @return			body of the corresponding OID
+ * @return			body of the corresponding OID, allocated
  */
 chunk_t asn1_algorithmIdentifier(int oid);
 
@@ -101,7 +102,7 @@ chunk_t asn1_algorithmIdentifier(int oid);
  * Converts an ASN.1 OID into a known OID index
  *
  * @param object	body of an OID
- * @return			index into the oid_names[] table or OID_UNKNOWN  
+ * @return			index into the oid_names[] table or OID_UNKNOWN
  */
 int asn1_known_oid(chunk_t object);
 
@@ -122,13 +123,22 @@ chunk_t asn1_build_known_oid(int n);
  */
 size_t asn1_length(chunk_t *blob);
 
+/**
+ * Unwrap the inner content of an ASN.1 type/length wrapped object.
+ *
+ * @param blob		blob to parse header from, moved behind parsed content
+ * @param content	inner content
+ * @return			parsed type, ASN1_INVALID if length parsing failed
+ */
+int asn1_unwrap(chunk_t *blob, chunk_t *content);
+
 /**
  * Parses an ASN.1 algorithmIdentifier object
  *
  * @param blob		ASN.1 coded blob
  * @param level0	top-most level offset
  * @param params	returns optional [ASN.1 coded] parameters
- * @return			known OID index or OID_UNKNOWN	
+ * @return			known OID index or OID_UNKNOWN
  */
 int asn1_parse_algorithmIdentifier(chunk_t blob, int level0, chunk_t *params);
 
@@ -167,7 +177,7 @@ time_t asn1_to_time(const chunk_t *utctime, asn1_t type);
  *
  * @param time		time_t in UTC
  * @param type		ASN1_UTCTIME or ASN1_GENERALIZEDTIME
- * @return			body of an ASN.1 code time object			
+ * @return			body of an ASN.1 code time object
  */
 chunk_t asn1_from_time(const time_t *time, asn1_t type);
 
@@ -176,7 +186,7 @@ chunk_t asn1_from_time(const time_t *time, asn1_t type);
  *
  * @param blob		ASN.1 coded time object
  * @param level0	top-most level offset
- * @return			time_t in UTC 	
+ * @return			time_t in UTC
  */
 time_t asn1_parse_time(chunk_t blob, int level0);
 
@@ -239,8 +249,12 @@ chunk_t asn1_integer(const char *mode, chunk_t content);
 /**
  * Build an ASN.1 object from a variable number of individual chunks
  *
+ * The mode string specifies the number of chunks, and how to handle each of
+ * them with a single character: 'c' for copy (allocate new chunk), 'm' for move
+ * (free given chunk) or 's' for sensitive-copy (clear given chunk, then free).
+ *
  * @param type		ASN.1 type to be created
- * @param mode		for each list member: 'c' for copy or 'm' for move
+ * @param mode		for each list member: 'c', 'm' or 's'
  * @return			chunk containing the ASN.1 coded object
  */
 chunk_t asn1_wrap(asn1_t type, const char *mode, ...);
