@@ -26,7 +26,8 @@ typedef struct printf_hook_t printf_hook_t;
 typedef struct printf_hook_spec_t printf_hook_spec_t;
 typedef enum printf_hook_argtype_t printf_hook_argtype_t;
 
-#if defined(HAVE_PRINTF_HOOKS) && !defined(USE_VSTR)
+#if !defined(USE_VSTR) && \
+	(defined(HAVE_PRINTF_FUNCTION) || defined(HAVE_PRINTF_SPECIFIER))
 
 #include <stdio.h>
 #include <printf.h>
@@ -77,7 +78,7 @@ int vstr_wrapper_vsnprintf(char *str, size_t size, const char *format, va_list a
 
 /**
  * Callback function type for printf hooks.
- * 
+ *
  * @param dst		destination buffer
  * @param len		length of the buffer
  * @param spec		format specifier
@@ -111,12 +112,12 @@ struct printf_hook_spec_t {
 	 * TRUE if a '#' was used in the format specifier
 	 */
 	int hash;
-	
+
 	/**
 	 * TRUE if a '-' was used in the format specifier
 	 */
 	int minus;
-	
+
 	/**
 	 * The width as given in the format specifier.
 	 */
@@ -127,7 +128,7 @@ struct printf_hook_spec_t {
  * Printf handler management.
  */
 struct printf_hook_t {
-	
+
 	/**
 	 * Register a printf handler.
 	 *
@@ -137,11 +138,11 @@ struct printf_hook_t {
 	 */
 	void (*add_handler)(printf_hook_t *this, char spec,
 						printf_hook_function_t hook, ...);
-	
+
 	/**
-     * Destroy a printf_hook instance.
-     */
-    void (*destroy)(printf_hook_t *this);
+	 * Destroy a printf_hook instance.
+	 */
+	void (*destroy)(printf_hook_t *this);
 };
 
 /**
