@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Tobias Brunner
+ * Copyright (C) 2008-2010 Tobias Brunner
  * Copyright (C) 2005-2008 Martin Willi
  * Hochschule fuer Technik Rapperswil
  *
@@ -20,12 +20,13 @@
 #include <string.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <stdint.h>
 #include <limits.h>
 #include <dirent.h>
 #include <time.h>
 
-#include <enum.h>
-#include <debug.h>
+#include "enum.h"
+#include "debug.h"
 
 ENUM(status_names, SUCCESS, DESTROY_ME,
 	"SUCCESS",
@@ -49,29 +50,52 @@ void *clalloc(void * pointer, size_t size)
 {
 	void *data;
 	data = malloc(size);
-	
+
 	memcpy(data, pointer, size);
-	
+
 	return (data);
 }
 
 /**
  * Described in header.
  */
-void memxor(u_int8_t dest[], u_int8_t src[], size_t n)
+void memxor(u_int8_t dst[], u_int8_t src[], size_t n)
 {
-	int i = 0, m;
-	
-	m = n - sizeof(long);
-	while (i < m)
+	int m, i;
+
+	/* byte wise XOR until dst aligned */
+	for (i = 0; (uintptr_t)&dst[i] % sizeof(long) && i < n; i++)
 	{
-		*(long*)(dest + i) ^= *(long*)(src + i);
-		i += sizeof(long);
+		dst[i] ^= src[i];
 	}
-	while (i < n)
+	/* try to use words if src shares an aligment with dst */
+	switch (((uintptr_t)&src[i] % sizeof(long)))
 	{
-		dest[i] ^= src[i];
-		i++;
+		case 0:
+			for (m = n - sizeof(long); i <= m; i += sizeof(long))
+			{
+				*(long*)&dst[i] ^= *(long*)&src[i];
+			}
+			break;
+		case sizeof(int):
+			for (m = n - sizeof(int); i <= m; i += sizeof(int))
+			{
+				*(int*)&dst[i] ^= *(int*)&src[i];
+			}
+			break;
+		case sizeof(short):
+			for (m = n - sizeof(short); i <= m; i += sizeof(short))
+			{
+				*(short*)&dst[i] ^= *(short*)&src[i];
+			}
+			break;
+		default:
+			break;
+	}
+	/* byte wise XOR of the rest */
+	for (; i < n; i++)
+	{
+		dst[i] ^= src[i];
 	}
 }
 
@@ -92,12 +116,34 @@ void *memstr(const void *haystack, const char *needle, size_t n)
 	return NULL;
 }
 
+/**
+ * Described in header.
+ */
+char* translate(char *str, const char *from, const char *to)
+{
+	char *pos = str;
+	if (strlen(from) != strlen(to))
+	{
+		return str;
+	}
+	while (pos && *pos)
+	{
+		char *match;
+		if ((match = strchr(from, *pos)) != NULL)
+		{
+			*pos = to[match - from];
+		}
+		pos++;
+	}
+	return str;
+}
+
 /**
  * Described in header.
  */
 bool mkdir_p(const char *path, mode_t mode)
 {
-	size_t len;
+	int len;
 	char *pos, full[PATH_MAX];
 	pos = full;
 	if (!path || *path == '\0')
@@ -107,7 +153,7 @@ bool mkdir_p(const char *path, mode_t mode)
 	len = snprintf(full, sizeof(full)-1, "%s", path);
 	if (len < 0 || len >= sizeof(full)-1)
 	{
-		DBG1("path string %s too long", path);
+		DBG1(DBG_LIB, "path string %s too long", path);
 		return FALSE;
 	}
 	/* ensure that the path ends with a '/' */
@@ -128,7 +174,7 @@ bool mkdir_p(const char *path, mode_t mode)
 		{
 			if (mkdir(full, mode) < 0)
 			{
-				DBG1("failed to create directory %s", full);
+				DBG1(DBG_LIB, "failed to create directory %s", full);
 				return FALSE;
 			}
 		}
@@ -138,6 +184,44 @@ bool mkdir_p(const char *path, mode_t mode)
 	return TRUE;
 }
 
+/**
+ * Return monotonic time
+ */
+time_t time_monotonic(timeval_t *tv)
+{
+#if defined(HAVE_CLOCK_GETTIME) && \
+	(defined(HAVE_CONDATTR_CLOCK_MONOTONIC) || \
+	 defined(HAVE_PTHREAD_COND_TIMEDWAIT_MONOTONIC))
+	/* as we use time_monotonic() for condvar operations, we use the
+	 * monotonic time source only if it is also supported by pthread. */
+	timespec_t ts;
+
+	if (clock_gettime(CLOCK_MONOTONIC, &ts) == 0)
+	{
+		if (tv)
+		{
+			tv->tv_sec = ts.tv_sec;
+			tv->tv_usec = ts.tv_nsec / 1000;
+		}
+		return ts.tv_sec;
+	}
+#endif /* HAVE_CLOCK_GETTIME && (...) */
+	/* Fallback to non-monotonic timestamps:
+	 * On MAC OS X, creating monotonic timestamps is rather difficult. We
+	 * could use mach_absolute_time() and catch sleep/wakeup notifications.
+	 * We stick to the simpler (non-monotonic) gettimeofday() for now.
+	 * But keep in mind: we need the same time source here as in condvar! */
+	if (!tv)
+	{
+		return time(NULL);
+	}
+	if (gettimeofday(tv, NULL) != 0)
+	{	/* should actually never fail if passed pointers are valid */
+		return -1;
+	}
+	return tv->tv_sec;
+}
+
 /**
  * return null
  */
@@ -173,7 +257,7 @@ void nop()
 #include <pthread.h>
 
 /**
- * We use a single mutex for all refcount variables. 
+ * We use a single mutex for all refcount variables.
  */
 static pthread_mutex_t ref_mutex = PTHREAD_MUTEX_INITIALIZER;
 
@@ -193,7 +277,7 @@ void ref_get(refcount_t *ref)
 bool ref_put(refcount_t *ref)
 {
 	bool more_refs;
-	
+
 	pthread_mutex_lock(&ref_mutex);
 	more_refs = --(*ref);
 	pthread_mutex_unlock(&ref_mutex);
@@ -214,7 +298,7 @@ int time_printf_hook(char *dst, size_t len, printf_hook_spec_t *spec,
 	time_t *time = *((time_t**)(args[0]));
 	bool utc = *((bool*)(args[1]));;
 	struct tm t;
-	
+
 	if (time == UNDEFINED_TIME)
 	{
 		return print_in_hook(dst, len, "--- -- --:--:--%s----",
@@ -243,7 +327,7 @@ int time_delta_printf_hook(char *dst, size_t len, printf_hook_spec_t *spec,
 	time_t *arg1 = *((time_t**)(args[0]));
 	time_t *arg2 = *((time_t**)(args[1]));
 	time_t delta = abs(*arg1 - *arg2);
-	
+
 	if (delta > 2 * 60 * 60 * 24)
 	{
 		delta /= 60 * 60 * 24;
@@ -277,7 +361,7 @@ int mem_printf_hook(char *dst, size_t dstlen,
 {
 	char *bytes = *((void**)(args[0]));
 	int len = *((size_t*)(args[1]));
-	
+
 	char buffer[BYTES_PER_LINE * 3];
 	char ascii_buffer[BYTES_PER_LINE + 1];
 	char *buffer_pos = buffer;
@@ -286,9 +370,9 @@ int mem_printf_hook(char *dst, size_t dstlen,
 	int line_start = 0;
 	int i = 0;
 	int written = 0;
-	
+
 	written += print_in_hook(dst, dstlen, "=> %d bytes @ %p", len, bytes);
-	
+
 	while (bytes_pos < bytes_roof)
 	{
 		*buffer_pos++ = hexdig_upper[(*bytes_pos >> 4) & 0xF];
@@ -297,20 +381,20 @@ int mem_printf_hook(char *dst, size_t dstlen,
 		ascii_buffer[i++] =
 				(*bytes_pos > 31 && *bytes_pos < 127) ? *bytes_pos : '.';
 
-		if (++bytes_pos == bytes_roof || i == BYTES_PER_LINE) 
+		if (++bytes_pos == bytes_roof || i == BYTES_PER_LINE)
 		{
 			int padding = 3 * (BYTES_PER_LINE - i);
-			
+
 			while (padding--)
 			{
 				*buffer_pos++ = ' ';
 			}
 			*buffer_pos++ = '\0';
 			ascii_buffer[i] = '\0';
-			
+
 			written += print_in_hook(dst, dstlen, "\n%4d: %s  %s",
-								     line_start, buffer, ascii_buffer);
-			
+									 line_start, buffer, ascii_buffer);
+
 			buffer_pos = buffer;
 			line_start += BYTES_PER_LINE;
 			i = 0;
