@@ -21,12 +21,12 @@
 #include "log.h"
 
 static struct encrypt_desc encrypt_desc_3des =
-{       
+{
 	algo_type:       IKE_ALG_ENCRYPT,
-	algo_id:         OAKLEY_3DES_CBC, 
+	algo_id:         OAKLEY_3DES_CBC,
 	algo_next:       NULL,
 
-	enc_blocksize:	 DES_BLOCK_SIZE, 
+	enc_blocksize:	 DES_BLOCK_SIZE,
 	keydeflen:		 DES_BLOCK_SIZE * 3 * BITS_PER_BYTE,
 	keyminlen:		 DES_BLOCK_SIZE * 3 * BITS_PER_BYTE,
 	keymaxlen:		 DES_BLOCK_SIZE * 3 * BITS_PER_BYTE,
@@ -40,7 +40,7 @@ static struct encrypt_desc encrypt_desc_aes =
 {
 	algo_type: 	     IKE_ALG_ENCRYPT,
 	algo_id:   	     OAKLEY_AES_CBC,
-	algo_next: 	     NULL, 
+	algo_next: 	     NULL,
 
 	enc_blocksize: 	 AES_BLOCK_SIZE,
 	keyminlen: 		 AES_KEY_MIN_LEN,
@@ -48,6 +48,22 @@ static struct encrypt_desc encrypt_desc_aes =
 	keymaxlen: 		 AES_KEY_MAX_LEN,
 };
 
+#define  CAMELLIA_KEY_MIN_LEN	128
+#define  CAMELLIA_KEY_DEF_LEN	128
+#define  CAMELLIA_KEY_MAX_LEN	256
+
+static struct encrypt_desc encrypt_desc_camellia =
+{
+	algo_type: 	     IKE_ALG_ENCRYPT,
+	algo_id:   	     OAKLEY_CAMELLIA_CBC,
+	algo_next: 	     NULL,
+
+	enc_blocksize: 	 CAMELLIA_BLOCK_SIZE,
+	keyminlen: 		 CAMELLIA_KEY_MIN_LEN,
+	keydeflen: 		 CAMELLIA_KEY_DEF_LEN,
+	keymaxlen: 		 CAMELLIA_KEY_MAX_LEN,
+};
+
 #define  BLOWFISH_KEY_MIN_LEN	128
 #define  BLOWFISH_KEY_MAX_LEN	448
 
@@ -55,7 +71,7 @@ static struct encrypt_desc encrypt_desc_blowfish =
 {
 	algo_type:       IKE_ALG_ENCRYPT,
 	algo_id:         OAKLEY_BLOWFISH_CBC,
-	algo_next:       NULL, 
+	algo_next:       NULL,
 
 	enc_blocksize:	 BLOWFISH_BLOCK_SIZE,
 	keyminlen:		 BLOWFISH_KEY_MIN_LEN,
@@ -83,7 +99,7 @@ static struct encrypt_desc encrypt_desc_serpent =
 #define  TWOFISH_KEY_DEF_LEN	128
 #define  TWOFISH_KEY_MAX_LEN	256
 
-static struct encrypt_desc encrypt_desc_twofish = 
+static struct encrypt_desc encrypt_desc_twofish =
 {
 	algo_type: 	     IKE_ALG_ENCRYPT,
 	algo_id:   	     OAKLEY_TWOFISH_CBC,
@@ -108,18 +124,18 @@ static struct encrypt_desc encrypt_desc_twofish_ssh =
 };
 
 static struct hash_desc hash_desc_md5 =
-{       
+{
 	algo_type: IKE_ALG_HASH,
 	algo_id:   OAKLEY_MD5,
-	algo_next: NULL, 
+	algo_next: NULL,
 	hash_digest_size: HASH_SIZE_MD5,
 };
 
 static struct hash_desc hash_desc_sha1 =
-{       
+{
 	algo_type: IKE_ALG_HASH,
 	algo_id:   OAKLEY_SHA,
-	algo_next: NULL, 
+	algo_next: NULL,
 	hash_digest_size: HASH_SIZE_SHA1,
 };
 
@@ -146,96 +162,117 @@ static struct hash_desc hash_desc_sha2_512 = {
 
 const struct dh_desc unset_group = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_NONE, 
+	algo_id:    MODP_NONE,
 	algo_next:  NULL,
 	ke_size:    0
 };
 
-static struct dh_desc dh_desc_modp_1024 = {       
+static struct dh_desc dh_desc_modp_1024 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_1024_BIT, 
+	algo_id:    MODP_1024_BIT,
 	algo_next:  NULL,
 	ke_size:    1024 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_modp_1536 = {       
+static struct dh_desc dh_desc_modp_1536 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_1536_BIT, 
+	algo_id:    MODP_1536_BIT,
 	algo_next:  NULL,
 	ke_size:    1536 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_modp_2048 = {       
+static struct dh_desc dh_desc_modp_2048 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_2048_BIT, 
+	algo_id:    MODP_2048_BIT,
 	algo_next:  NULL,
 	ke_size:    2048 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_modp_3072 = {       
+static struct dh_desc dh_desc_modp_3072 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_3072_BIT, 
+	algo_id:    MODP_3072_BIT,
 	algo_next:  NULL,
 	ke_size:    3072 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_modp_4096 = {       
+static struct dh_desc dh_desc_modp_4096 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_4096_BIT, 
+	algo_id:    MODP_4096_BIT,
 	algo_next:  NULL,
 	ke_size:    4096 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_modp_6144 = {       
+static struct dh_desc dh_desc_modp_6144 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_6144_BIT, 
+	algo_id:    MODP_6144_BIT,
 	algo_next:  NULL,
 	ke_size:    6144 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_modp_8192 = {       
+static struct dh_desc dh_desc_modp_8192 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    MODP_8192_BIT, 
+	algo_id:    MODP_8192_BIT,
 	algo_next:  NULL,
 	ke_size:    8192 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_ecp_256 = {       
+static struct dh_desc dh_desc_ecp_256 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    ECP_256_BIT, 
+	algo_id:    ECP_256_BIT,
 	algo_next:  NULL,
 	ke_size:    2*256 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_ecp_384 = {       
+static struct dh_desc dh_desc_ecp_384 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    ECP_384_BIT, 
+	algo_id:    ECP_384_BIT,
 	algo_next:  NULL,
 	ke_size:    2*384 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_ecp_521 = {       
+static struct dh_desc dh_desc_ecp_521 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    ECP_521_BIT, 
+	algo_id:    ECP_521_BIT,
 	algo_next:  NULL,
 	ke_size:    2*528 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_ecp_192 = {       
+static struct dh_desc dh_desc_modp_1024_160 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    ECP_192_BIT, 
+	algo_id:    MODP_1024_160,
+	algo_next:  NULL,
+	ke_size:    1024 / BITS_PER_BYTE
+};
+
+static struct dh_desc dh_desc_modp_2048_224 = {
+	algo_type:  IKE_ALG_DH_GROUP,
+	algo_id:    MODP_2048_224,
+	algo_next:  NULL,
+	ke_size:    2048 / BITS_PER_BYTE
+};
+
+static struct dh_desc dh_desc_modp_2048_256 = {
+	algo_type:  IKE_ALG_DH_GROUP,
+	algo_id:    MODP_2048_256,
+	algo_next:  NULL,
+	ke_size:    2048 / BITS_PER_BYTE
+};
+
+static struct dh_desc dh_desc_ecp_192 = {
+	algo_type:  IKE_ALG_DH_GROUP,
+	algo_id:    ECP_192_BIT,
 	algo_next:  NULL,
 	ke_size:    2*192 / BITS_PER_BYTE
 };
 
-static struct dh_desc dh_desc_ecp_224 = {       
+static struct dh_desc dh_desc_ecp_224 = {
 	algo_type:  IKE_ALG_DH_GROUP,
-	algo_id:    ECP_224_BIT, 
+	algo_id:    ECP_224_BIT,
 	algo_next:  NULL,
 	ke_size:    2*224 / BITS_PER_BYTE
 };
 
-void init_crypto(void)
+bool init_crypto(void)
 {
 	enumerator_t *enumerator;
 	encryption_algorithm_t encryption_alg;
@@ -275,20 +312,20 @@ void init_crypto(void)
 	}
 	enumerator->destroy(enumerator);
 
-	if (no_sha1)
+	if (no_sha1 || no_md5)
 	{
-		exit_log("pluto cannot run without a SHA-1 hasher");
+		plog("pluto cannot run without a %s%s%s hasher",
+			 (no_sha1) ? "SHA-1" : "",
+			 (no_sha1 && no_md5) ? " and " : "",
+			 (no_md5) ? "MD5" : "");
+		return FALSE;
 	}
-	if (no_md5)
-	{
-		exit_log("pluto cannot run without an MD5 hasher");
-	}
-		
+
 	enumerator = lib->crypto->create_crypter_enumerator(lib->crypto);
 	while (enumerator->enumerate(enumerator, &encryption_alg))
 	{
 		const struct encrypt_desc *desc;
- 
+
 		switch (encryption_alg)
 		{
 			case ENCR_3DES:
@@ -300,6 +337,9 @@ void init_crypto(void)
 			case ENCR_AES_CBC:
 				desc = &encrypt_desc_aes;
 				break;
+			case ENCR_CAMELLIA_CBC:
+				desc = &encrypt_desc_camellia;
+				break;
 			case ENCR_TWOFISH_CBC:
 				desc = &encrypt_desc_twofish;
 				ike_alg_add((struct ike_alg *)&encrypt_desc_twofish_ssh);
@@ -308,7 +348,7 @@ void init_crypto(void)
 				desc = &encrypt_desc_serpent;
 				break;
 			default:
-				continue;			
+				continue;
 		}
 		ike_alg_add((struct ike_alg *)desc);
 	}
@@ -351,6 +391,15 @@ void init_crypto(void)
 			case ECP_521_BIT:
 				desc = &dh_desc_ecp_521;
 				break;
+			case MODP_1024_160:
+				desc = &dh_desc_modp_1024_160;
+				break;
+			case MODP_2048_224:
+				desc = &dh_desc_modp_2048_224;
+				break;
+			case MODP_2048_256:
+				desc = &dh_desc_modp_2048_256;
+				break;
 			case ECP_192_BIT:
 				desc = &dh_desc_ecp_192;
 				break;
@@ -363,6 +412,7 @@ void init_crypto(void)
 		ike_alg_add((struct ike_alg *)desc);
 	}
 	enumerator->destroy(enumerator);
+	return TRUE;
 }
 
 void free_crypto(void)
@@ -380,7 +430,7 @@ encryption_algorithm_t oakley_to_encryption_algorithm(int alg)
 		case OAKLEY_DES_CBC:
 			return ENCR_DES;
 		case OAKLEY_IDEA_CBC:
-			return ENCR_IDEA; 
+			return ENCR_IDEA;
 		case OAKLEY_BLOWFISH_CBC:
 			return ENCR_BLOWFISH;
 		case OAKLEY_RC5_R16_B64_CBC:
@@ -391,6 +441,8 @@ encryption_algorithm_t oakley_to_encryption_algorithm(int alg)
 			return ENCR_CAST;
 		case OAKLEY_AES_CBC:
 			return ENCR_AES_CBC;
+		case OAKLEY_CAMELLIA_CBC:
+			return ENCR_CAMELLIA_CBC;
 		case OAKLEY_SERPENT_CBC:
 			return ENCR_SERPENT_CBC;
 		case OAKLEY_TWOFISH_CBC:
@@ -490,7 +542,7 @@ int oakley_from_encryption_algorithm(encryption_algorithm_t alg)
 			return OAKLEY_CAMELLIA_CBC;
 		case ENCR_SERPENT_CBC:
 			return OAKLEY_SERPENT_CBC;
-    	case ENCR_TWOFISH_CBC:
+	case ENCR_TWOFISH_CBC:
 			return OAKLEY_TWOFISH_CBC;
 		default:
 			return 0;
@@ -558,9 +610,11 @@ int esp_from_encryption_algorithm(encryption_algorithm_t alg)
 			return ESP_AES_GCM_16;
 		case ENCR_CAMELLIA_CBC:
 			return ESP_CAMELLIA;
+		case ENCR_NULL_AUTH_AES_GMAC:
+			return ESP_AES_GMAC;
 		case ENCR_SERPENT_CBC:
 			return ESP_SERPENT;
-    	case ENCR_TWOFISH_CBC:
+		case ENCR_TWOFISH_CBC:
 			return ESP_TWOFISH;
 		default:
 			return 0;
@@ -580,12 +634,20 @@ int esp_from_integrity_algorithm(integrity_algorithm_t alg)
 			return AUTH_ALGORITHM_HMAC_SHA1;
 		case AUTH_AES_XCBC_96:
 			return AUTH_ALGORITHM_AES_XCBC_MAC;
+		case AUTH_HMAC_SHA2_256_96:
+			return AUTH_ALGORITHM_HMAC_SHA2_256_96;
 		case AUTH_HMAC_SHA2_256_128:
 			return AUTH_ALGORITHM_HMAC_SHA2_256;
 		case AUTH_HMAC_SHA2_384_192:
 			return AUTH_ALGORITHM_HMAC_SHA2_384;
 		case AUTH_HMAC_SHA2_512_256:
 			return AUTH_ALGORITHM_HMAC_SHA2_512;
+		case AUTH_AES_128_GMAC:
+			return AUTH_ALGORITHM_AES_128_GMAC;
+		case AUTH_AES_192_GMAC:
+			return AUTH_ALGORITHM_AES_192_GMAC;
+		case AUTH_AES_256_GMAC:
+			return AUTH_ALGORITHM_AES_256_GMAC;
 		default:
 			return 0;
 	}
