@@ -147,7 +147,7 @@ static void _natd_hash(const struct hash_desc *oakley_hasher, char *hash,
 				addr_chunk = chunk_from_thing(ip->u.v6.sin6_addr.s6_addr);
 				break;
 			default:
-				addr_chunk = chunk_empty; /* should never occur */ 
+				addr_chunk = chunk_empty; /* should never occur */
 		}
 		hasher->get_hash(hasher, addr_chunk, NULL);
 		hasher->get_hash(hasher, port_chunk, hash);
@@ -310,7 +310,7 @@ bool nat_traversal_add_natd(u_int8_t np, pb_stream *outs,
 	DBG(DBG_EMITTING,
 		DBG_log("sending NATD payloads")
 	)
-		
+
 	/*
 	 * First one with sender IP & port
 	 */
@@ -348,7 +348,7 @@ bool nat_traversal_add_natd(u_int8_t np, pb_stream *outs,
 
 /*
  * nat_traversal_natoa_lookup()
- * 
+ *
  * Look for NAT-OA in message
  */
 void nat_traversal_natoa_lookup(struct msg_digest *md)
@@ -435,7 +435,7 @@ void nat_traversal_natoa_lookup(struct msg_digest *md)
 		{
 			char ip_t[ADDRTOT_BUF];
 			addrtot(&ip, 0, ip_t, sizeof(ip_t));
-		
+
 			DBG_log("received NAT-OA: %s", ip_t);
 		}
 	)
@@ -514,7 +514,7 @@ void nat_traversal_show_result (u_int32_t nt, u_int16_t sport)
 		mth = natt_type_bitnames[2];
 		break;
 	}
-	
+
 	switch (nt & NAT_T_DETECTED)
 	{
 	case 0:
@@ -600,7 +600,7 @@ static void nat_traversal_send_ka (struct state *st)
 static void nat_traversal_ka_event_state (struct state *st, void *data)
 {
 	unsigned int *_kap_st = (unsigned int *)data;
-	const struct connection *c = st->st_connection;
+	const connection_t *c = st->st_connection;
 
 	if (!c)
 		return;
@@ -658,7 +658,7 @@ struct _new_mapp_nfo {
 
 static void nat_traversal_find_new_mapp_state (struct state *st, void *data)
 {
-	struct connection *c = st->st_connection;
+	connection_t *c = st->st_connection;
 	struct _new_mapp_nfo *nfo = (struct _new_mapp_nfo *)data;
 
 	if (c != NULL
@@ -720,7 +720,7 @@ static int nat_traversal_new_mapping(const ip_address *src, u_int16_t sport,
 
 void nat_traversal_change_port_lookup(struct msg_digest *md, struct state *st)
 {
-	struct connection *c = st ? st->st_connection : NULL;
+	connection_t *c = st ? st->st_connection : NULL;
 	struct iface *i = NULL;
 
 	if ((st == NULL) || (c == NULL))
@@ -804,7 +804,7 @@ struct _new_klips_mapp_nfo {
 
 static void nat_t_new_klips_mapp (struct state *st, void *data)
 {
-	struct connection *c = st->st_connection;
+	connection_t *c = st->st_connection;
 	struct _new_klips_mapp_nfo *nfo = (struct _new_klips_mapp_nfo *)data;
 
 	if (c != NULL && st->st_esp.present
