@@ -93,12 +93,17 @@ typedef enum {
 	KW_INACTIVITY,
 	KW_MODECONFIG,
 	KW_XAUTH,
+	KW_XAUTH_IDENTITY,
 	KW_MEDIATION,
 	KW_MEDIATED_BY,
 	KW_ME_PEERID,
+	KW_REQID,
+	KW_MARK,
+	KW_MARK_IN,
+	KW_MARK_OUT,
 
 #define KW_CONN_FIRST   KW_CONN_SETUP
-#define KW_CONN_LAST    KW_ME_PEERID
+#define KW_CONN_LAST    KW_MARK_OUT
 
    /* ca section keywords */
 	KW_CA_NAME,
