@@ -11,8 +11,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- *
- * RCSID $Id: stroke_keywords.h 3271 2007-10-08 20:12:25Z andreas $
  */
 
 #ifndef _STROKE_KEYWORDS_H_
@@ -26,9 +24,11 @@ typedef enum {
 	STROKE_UNROUTE,
 	STROKE_UP,
 	STROKE_DOWN,
+	STROKE_DOWN_SRCIP,
 	STROKE_LOGLEVEL,
 	STROKE_STATUS,
 	STROKE_STATUSALL,
+	STROKE_LIST_PUBKEYS,
 	STROKE_LIST_CERTS,
 	STROKE_LIST_CACERTS,
 	STROKE_LIST_OCSPCERTS,
@@ -38,6 +38,7 @@ typedef enum {
 	STROKE_LIST_CAINFOS,
 	STROKE_LIST_CRLS,
 	STROKE_LIST_OCSP,
+	STROKE_LIST_ALGS,
 	STROKE_LIST_ALL,
 	STROKE_REREAD_SECRETS,
 	STROKE_REREAD_CACERTS,
@@ -46,10 +47,12 @@ typedef enum {
 	STROKE_REREAD_ACERTS,
 	STROKE_REREAD_CRLS,
 	STROKE_REREAD_ALL,
-	STROKE_PURGE_OCSP
+	STROKE_PURGE_OCSP,
+	STROKE_PURGE_IKE,
+	STROKE_LEASES
 } stroke_keyword_t;
 
-#define STROKE_LIST_FIRST		STROKE_LIST_CERTS
+#define STROKE_LIST_FIRST		STROKE_LIST_PUBKEYS
 #define STROKE_REREAD_FIRST		STROKE_REREAD_SECRETS
 #define STROKE_PURGE_FIRST		STROKE_PURGE_OCSP
 
