@@ -227,6 +227,7 @@ struct stroke_msg_t {
 			time_t inactivity;
 			int proxy_mode;
 			int install_policy;
+			u_int32_t reqid;
 
 			crl_policy_t crl_policy;
 			int unique;
@@ -255,6 +256,10 @@ struct stroke_msg_t {
 				char *mediated_by;
 				char *peerid;
 			} ikeme;
+			struct {
+				u_int32_t value;
+				u_int32_t mask;
+			} mark_in, mark_out;
 			stroke_end_t me, other;
 		} add_conn;
 
